@@ -46,6 +46,7 @@ from core import signal
 from core.backports import six
 from core import constants
 from core.threads import threadMgr
+from core import geo
 
 SEARCH_STATUS_PREFIX = "search:status:"
 SEARCH_RESULT_PREFIX = "search:result:"
@@ -68,7 +69,8 @@ def point2dict(point):
         "description" : point.description,
         "latitude" : point.lat,
         "longitude" : point.lon,
-        "elevation" : point.elevation
+        "elevation" : point.elevation,
+        "highlight" : False
     }
 
 
@@ -226,6 +228,11 @@ class QMLGUI(GUIModule):
         lat, lon = float(posDict["latitude"]), float(posDict["longitude"])
         elevation = float(posDict["elevation"])
         metersPerSecSpeed = float(posDict["speedMPS"])  # m/s
+        # report that we have 3D fix
+        # (looks like we can't currently reliably discern between 2D
+        # and 3D fix on the Jolla, might be good to check what other
+        # Sailfish OS running devices report)
+        self.set("fix", 3)
 
         self.set("pos", (lat, lon))
 
@@ -307,7 +314,10 @@ class QMLGUI(GUIModule):
             print(e)
 
 class Modules(object):
-    """A class that provides access to modRana modules from the QML context"""
+    """A class that provides access to modRana modules from the QML context,
+       using the __getattr__ method so that QML can access all modules dynamically
+       with normal dot notation
+    """
 
     def __init__(self, gui):
         self._info = None
@@ -317,40 +327,9 @@ class Modules(object):
         self._storeTiles = None
         self.gui = gui
 
-    @property
-    def info(self):
-        """A lazy evaluated property providing access to the info module"""
-        if self._info is None:
-            self._info = self.gui.m.get("info")
-        return self._info
-    
-    @property
-    def stats(self):
-        """A lazy evaluated property providing access to the stats module"""
-        if self._stats is None:
-            self._stats = self.gui.m.get("stats")
-        return self._stats
+    def __getattr__(self, moduleName):
+        return self.gui.m.get(moduleName, None)
 
-    @property
-    def mapLayers(self):
-        """A lazy evaluated property providing access to the stats module"""
-        if self._mapLayers is None:
-            self._mapLayers = self.gui.m.get("mapLayers")
-        return self._mapLayers
-
-    @property
-    def mapTiles(self):
-        """A lazy evaluated property providing access to the mapTiles module"""
-        if self._mapTiles is None:
-            self._mapTiles = self.gui.m.get("mapTiles")
-        return self._mapTiles
-
-    @property
-    def storeTiles(self):
-        """A lazy evaluated property providing access to the storeTiles module"""
-        if self._storeTiles is None:
-            self._storeTiles = self.gui.m.get("storeTiles")
-        return self._storeTiles
 
 class Search(object):
     """An easy to use search interface for the QML context"""
@@ -367,7 +346,6 @@ class Search(object):
 
         :param str query: search query
         """
-
         online = self.gui.m.get("onlineServices", None)
         if online:
             # construct result handling callback
@@ -387,6 +365,16 @@ class Search(object):
 
         :param list results: address search results
         """
+        # try to sort local search results by distance
+        # TODO: make this configurable
+        if searchId == "local":
+            pos = self.gui.get("pos", None)
+            if pos:
+                distanceList = []
+                for result in results:
+                    distanceList.append((geo.distanceP2LL(result,pos[0], pos[1]), result))
+                distanceList.sort()
+                results = map(lambda x: x[1], distanceList)
         # covert the Points in the results to a list of dicts
         resultList = []
         for result in results:
@@ -416,16 +404,20 @@ class Search(object):
 
     def _getSearchFunction(self, searchId):
         """Return the search function object for the given searchId"""
-        if searchId in ("address", "wikipedia"):
-            online = self.gui.m.get("onlineServices", None)
-            if online:
-                if searchId == "address":
-                    return online.geocodeAsync
-                elif searchId == "wikipedia":
-                    return online.wikipediaSearchAsync
+        online = self.gui.m.get("onlineServices", None)
+        if online:
+            if searchId == "address":
+                return online.geocodeAsync
+            elif searchId == "wikipedia":
+                return online.wikipediaSearchAsync
+            elif searchId == "local":
+                return online.localSearchAsync
             else:
                 print("Qt5 GUI: search function for id: %s not found" % searchId)
                 return None
+        else:
+            print("Qt5 GUI: onlineServices module not found")
+
 
 class ImageProvider(object):
     """PyOtherSide image provider base class"""
