@@ -53,7 +53,7 @@ class Tracklog(RanaModule):
         RanaModule.__init__(self, m, d, i)
         self.loggingEnabled = False
         self.loggingPaused = False
-        self.loggingStartTimestamp = None
+        self.loggingStartTimestamp = 0
         self.logInterval = 1 #loggin interval in seconds
         self.saveInterval = 10 #saving interval in seconds
         self.lastUpdateTimestamp = None
@@ -61,6 +61,7 @@ class Tracklog(RanaModule):
         self.logName = None #name of the current log
         self.logFilename = None #name of the current log
         self.logPath = None #path to the current log
+        self.currentLogGPX = None
         self.currentTempLog = []
         # primary and secondary AOWay objects for
         # persistent log storage during logging
@@ -70,11 +71,11 @@ class Tracklog(RanaModule):
         self.updateLogTimerId = None
         self.saveLogTimerId = None
         # statistics
-        self.maxSpeed = None
+        self.maxSpeed = 0
         self.avg1 = 0
         self.avg2 = 0
-        self.avgSpeed = None
-        self.distance = None
+        self.avgSpeed = 0
+        self.distance = 0
         self.toolsMenuDone = False
         self.category = 'logs'
         # trace
@@ -82,6 +83,8 @@ class Tracklog(RanaModule):
         self.lastTracePoint = None
         self.traceIndex = 0
         self.pxpyIndex = deque()
+        self.lastX = 0
+        self.lastY = 0
 
     #    self.startupTimestamp = time.strftime("%Y%m%dT%H%M%S")
 
@@ -248,7 +251,15 @@ class Tracklog(RanaModule):
                     lat1, lon1 = self.lastTracePoint
                     # check if the point is distant enough from the last added point
                     # (which was either the first point or also passed the test)
-                    if geo.distanceApprox(lat, lon, lat1, lon1) * 1000 >= DONT_ADD_TO_TRACE_THRESHOLD:
+                    addToTrace = True
+                    try:
+                        addToTrace = geo.distanceApprox(lat, lon, lat1, lon1) * 1000 >= DONT_ADD_TO_TRACE_THRESHOLD
+                    except Exception:
+                        import sys
+                        e = sys.exc_info()[1]
+                        print("tracklog: measuring distance failed (yeah, really! :P), adding point anyway")
+                        print(e)
+                    if addToTrace:
                         self._addLL2Trace(lat, lon)
                 else: # this is the first known log point, just add it
                     self._addLL2Trace(lat, lon)
@@ -278,7 +289,6 @@ class Tracklog(RanaModule):
             self.log1.flush()
         except Exception:
             import sys
-
             e = sys.exc_info()[1]
             print('tracklog: saving primary temporary log failed')
             print(e)
@@ -286,7 +296,6 @@ class Tracklog(RanaModule):
             self.log2.flush()
         except Exception:
             import sys
-
             e = sys.exc_info()[1]
             print('tracklog: saving secondary temporary log failed')
             print(e)
@@ -425,8 +434,8 @@ class Tracklog(RanaModule):
         #cr.set_source_rgb(0.0, 0.0, 0.8)
         cr.line_to(x, y)
         cr.stroke()
-        self.lastx = x
-        self.lasty = y
+        self.lastX = x
+        self.lastY = y
 
     #    s = 2 #default 2
     #    cr.rectangle(x-s,y-s,2*s,2*s)
@@ -751,11 +760,4 @@ class Tracklog(RanaModule):
     def shutdown(self):
         # try to stop and save the log
         if self.loggingEnabled:
-            self.stopLogging()
-
-
-
-
-
-
-
+            self.stopLogging()
\ No newline at end of file
